type Option<T> = null | undefined | T;


/**
	Unwrap option of `null|undefined|T` to `T` throw error if value is not `T`.
    `expect()` is preferred to this function as it gives better error messages
 */
export function unwrap<T>(input: Option<T>): T {
	if (input === null || input === undefined) {
		throw new TypeError("Unwrap called on null/undefined value");
	}
	return input as T;
}

/**
	Unwrap option of `null|undefined|T` to `T` throw error with `exceptionMessage` if value is not `T`
 */
export function expect<T>(input: Option<T>, exceptionMessage: string): T {
	if (input === null || input === undefined) {
		throw new TypeError(exceptionMessage);
	}
	return input as T;
}
